@@ -785,7 +785,7 @@ INSERT INTO blacklist_macaddresses(MACADDRESS) VALUES ('00:00:00:00:00:00'),('FF
 
 INSERT INTO operators(ID,FIRSTNAME,LASTNAME,PASSWD,ACCESSLVL,COMMENTS) VALUES ('admin','admin','admin','admin',1, 'Default administrator account');
 
-INSERT INTO config VALUES ('GUI_VERSION', 0, '6004', 'Version of the installed GUI and database');
+INSERT INTO config VALUES ('GUI_VERSION', 0, '7006', 'Version of the installed GUI and database');
 
 CREATE TABLE download_servers (
   HARDWARE_ID int(11) NOT NULL,
@@ -897,8 +897,8 @@ ALTER TABLE hardware ADD COLUMN UUID VARCHAR(255) default NULL;
 ALTER TABLE operators ADD COLUMN NEW_ACCESSLVL VARCHAR(255) default NULL;
 ALTER TABLE operators ADD COLUMN EMAIL VARCHAR(255) default NULL;
 UPDATE operators SET NEW_ACCESSLVL='sadmin' where ACCESSLVL=1;
-UPDATE operators SET NEW_ACCESSLVL='ladmin' where ACCESSLVL=2;
-UPDATE operators SET NEW_ACCESSLVL='admin' where ACCESSLVL=3;
+UPDATE operators SET NEW_ACCESSLVL='admin' where ACCESSLVL=2;
+UPDATE operators SET NEW_ACCESSLVL='ladmin' where ACCESSLVL=3;
 ALTER TABLE operators ADD COLUMN USER_GROUP VARCHAR(255) default NULL;
 ALTER TABLE download_available ADD COLUMN ID_WK int(11) default NULL;
 
@@ -1019,7 +1019,7 @@ CREATE TABLE blacklist_subnet(
 ) ENGINE = MYISAM DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
 
 ALTER TABLE accountinfo_config ADD COLUMN ACCOUNT_TYPE VARCHAR(255) default NULL;
-INSERT INTO accountinfo_config VALUES (1,'TAG',0,'TAG',1,'TAG',1,'COMPUTERS'),(2,'TAG',0,'TAG',1,'TAG',1,'SNMP');
+INSERT INTO accountinfo_config (`ID`,`NAME_ACCOUNTINFO`,`TYPE`,`NAME`,`ID_TAB`,`COMMENT`,`SHOW_ORDER`,`ACCOUNT_TYPE`) VALUES (1,'TAG',0,'TAG',1,'TAG',1,'COMPUTERS'),(2,'TAG',0,'TAG',1,'TAG',1,'SNMP');
 UPDATE accountinfo_config SET ACCOUNT_TYPE='COMPUTERS' where ACCOUNT_TYPE IS NULL;
 
 
@@ -1352,4 +1352,83 @@ DESCRIPTION VARCHAR(255) DEFAULT NULL,
 PRIMARY KEY (ID) ) DEFAULT CHARSET=UTF8;
 
 INSERT INTO config VALUES ('DOWNLOAD_REDISTRIB',1,'','Use redistribution servers');
+ALTER TABLE snmp_loadbalancers ADD COLUMN MANUFACTURER varchar(255) DEFAULT NULL;
+ALTER TABLE snmp_loadbalancers ADD COLUMN TYPE varchar(255) DEFAULT NULL;
+ALTER TABLE hardware ADD COLUMN ARCH varchar(10) DEFAULT NULL;
 
+
+CREATE TABLE snmp_communities (
+ ID INTEGER NOT NULL auto_increment,
+ VERSION VARCHAR(5) default NULL,
+ NAME VARCHAR(255) default NULL,
+ USERNAME VARCHAR(255) default NULL,
+ AUTHKEY VARCHAR(255) default NULL,
+ AUTHPASSWD VARCHAR(255) default NULL,
+ PRIMARY KEY (ID)
+) ENGINE=INNODB ;
+
+DELETE FROM config WHERE name='SNMP_URI' or name='SNMP_DIR';
+ALTER TABLE accountinfo_config ADD COLUMN DEFAULT_VALUE varchar(255) DEFAULT NULL;
+INSERT INTO config VALUES ('LOG_DIR',0,'/var/lib/ocsinventory-reports','Directory for logs files');
+INSERT INTO config VALUES ('LOG_SCRIPT',0,'/var/lib/ocsinventory-reports','Directory for logs scripts files');
+INSERT INTO config VALUES ('WOL_PORT',0,'7,9','Wol ports');
+ALTER TABLE temp_files change file file longblob;
+CREATE TABLE cpus (
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  HARDWARE_ID int(11) NOT NULL,
+  MANUFACTURER varchar(255) DEFAULT NULL,
+  TYPE varchar(255) DEFAULT NULL,
+  SERIALNUMBER varchar(255) DEFAULT NULL,
+  SPEED varchar(255) DEFAULT NULL,
+  CORES int(11) DEFAULT NULL,
+  L2CACHESIZE varchar(255) DEFAULT NULL,
+  CPUARCH varchar(255) DEFAULT NULL,
+  DATA_WIDTH int(11) DEFAULT NULL,
+  CURRENT_ADDRESS_WIDTH int(11) DEFAULT NULL,
+  LOGICAL_CPUS int(11) DEFAULT NULL,
+  VOLTAGE varchar(255) DEFAULT NULL,
+  CURRENT_SPEED varchar(255) DEFAULT NULL,
+  SOCKET varchar(255) DEFAULT NULL,
+  PRIMARY KEY (`ID`,`HARDWARE_ID`)
+  ) ENGINE=InnoDB DEFAULT CHARSET=UTF8;
+
+CREATE TABLE sim (
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  HARDWARE_ID int(11) NOT NULL,
+  OPERATOR varchar(255) DEFAULT NULL,
+  OPNAME varchar(255) DEFAULT NULL,
+  COUNTRY varchar(255) DEFAULT NULL,
+  SERIALNUMBER varchar(255) DEFAULT NULL,
+   PRIMARY KEY (`ID`,`HARDWARE_ID`)
+  ) ENGINE=InnoDB DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_virtualmachines (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  CONFIG_FILE VARCHAR(255) DEFAULT NULL,
+  CPU INTEGER DEFAULT NULL,
+  MEMORY INTEGER DEFAULT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,
+  OS VARCHAR(255) DEFAULT NULL,
+  POWER VARCHAR(255) DEFAULT NULL,
+  UUID VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID,SNMP_ID)
+) ENGINE=InnoDB DEFAULT CHARSET=UTF8;
+
+ALTER TABLE printers ADD COLUMN SERVERNAME VARCHAR(255) DEFAULT NULL;
+ALTER TABLE printers ADD COLUMN SHARENAME VARCHAR(255) DEFAULT NULL;
+ALTER TABLE printers ADD COLUMN RESOLUTION VARCHAR(50) DEFAULT NULL;
+ALTER TABLE printers ADD COLUMN `COMMENT` VARCHAR(255) DEFAULT NULL;
+ALTER TABLE printers ADD COLUMN SHARED INTEGER DEFAULT NULL;
+ALTER TABLE printers ADD COLUMN NETWORK INTEGER DEFAULT NULL;
+ALTER TABLE sim ADD COLUMN DEVICEID VARCHAR(255) DEFAULT NULL;
+
+CREATE TABLE `snmp_mibs` (
+  `ID` INTEGER NOT NULL AUTO_INCREMENT,
+  `VENDOR` VARCHAR(255) DEFAULT NULL,
+  `URL` VARCHAR(255) DEFAULT NULL,
+  `CHECKSUM` VARCHAR(255) DEFAULT NULL,
+  `VERSION` VARCHAR(5) DEFAULT NULL,
+  `PARSER` VARCHAR(5) DEFAULT NULL,
+  PRIMARY KEY (`ID`)
+) ENGINE=InnoDB DEFAULT CHARSET=UTF8;
