@@ -14,14 +14,15 @@
 	$protectedPost['SHOW'] = 'NOSHOW';
 	$form_name="affich_memories";
 	$table_name=$form_name;
-	echo "<form name='".$form_name."' id='".$form_name."' method='POST' action=''>";
+	echo open_form($form_name);
 	$list_fields=array($l->g(80) => 'CAPTION',
 					   $l->g(53) => 'DESCRIPTION',
 					   $l->g(83)." (MB)" => 'CAPACITY',
 					   $l->g(283) => 'PURPOSE',
 					   $l->g(66) => 'TYPE',
 					   $l->g(268) => 'SPEED',
-					   $l->g(94) => 'NUMSLOTS');
+					   $l->g(94) => 'NUMSLOTS',
+					   $l->g(36)=>'SERIALNUMBER');
 					   
 					   
 	if($show_all_column)
@@ -32,5 +33,5 @@
 	$default_fields= $list_fields;
 	$queryDetails  = "SELECT * FROM memories WHERE (hardware_id=$systemid)";
 	tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$queryDetails,$form_name,80,$tab_options);
-	echo "</form>";
+	echo close_form();
 ?>
\ No newline at end of file
