@@ -17,12 +17,19 @@ foreach ($_POST as $key=>$value){
 }
 $protectedPost=$temp_post;
 if( isset( $protectedPost["VALID_END"] ) ) {
+	//configure description of this package
+	$description_details=$protectedPost['DESCRIPTION'];
+	if (isset($protectedPost['TYPE_PACK']) and $protectedPost['TYPE_PACK'] != '')
+		$description_details .= "  [Type=".$protectedPost['TYPE_PACK']."]";
+	if (isset($protectedPost['VISIBLE']) and $protectedPost['VISIBLE'] != '')
+		$description_details .= "  [VISIBLE=".$protectedPost['VISIBLE']."]";
+		
 	$sql_details=array('document_root'=>$protectedPost['document_root'],
 					   'timestamp'=>$protectedPost['timestamp'],
 					   'nbfrags'=>$protectedPost["nbfrags"],
 					   'name'=>$protectedPost['NAME'],
 					   'os'=>$protectedPost['OS'],
-					   'description'=>$protectedPost['DESCRIPTION'].'  [Type='.$protectedPost['TYPE_PACK']."]".'  [VISIBLE='.$protectedPost['VISIBLE']."]",
+					   'description'=>$description_details,
 					   'size'=>$protectedPost['SIZE'],
 					   'id_wk'=>$protectedPost['LIST_DDE_CREAT']);
 					   
@@ -47,12 +54,16 @@ if( isset( $protectedPost["VALID_END"] ) ) {
 	if ($protectedPost['REDISTRIB_USE'] == 1){
 		$timestamp_redistrib= time();
 		$server_dir=$protectedPost['download_rep_creat'];
+		$rep=$server_dir.$timestamp_redistrib;
 		//create zip file for redistribution servers
 		require_once("libraries/zip.lib.php");
 		$zipfile = new zipfile();
-		$rep = $protectedPost['document_root'].$sql_details['timestamp']."/";
-		@mkdir($server_dir);
-		@mkdir($server_dir.$timestamp_redistrib);
+		
+		if (!file_exists($server_dir)){
+			mkdir($server_dir);
+		}
+		if (!file_exists($server_dir.$timestamp_redistrib))
+			mkdir($rep);
 		$dir = opendir($rep);
 		while($f = readdir($dir)){
 		   if(is_file($rep.$f))
@@ -85,7 +96,7 @@ if( isset( $protectedPost["VALID_END"] ) ) {
 						'PROTO'=>$protectedPost['PROTOCOLE'],
 						'DIGEST_ALGO'=>$protectedPost["digest_algo"],
 						'DIGEST_ENCODE'=>$protectedPost["digest_encod"],
-						'PATH'=>$protectedPost['download_server_docroot'],
+						'PATH'=>$protectedPost['DOWNLOAD_SERVER_DOCROOT'],
 						'NAME'=>'',
 						'COMMAND'=>'',
 						'NOTIFY_USER'=>'0',
@@ -104,17 +115,29 @@ $lign_begin="<tr height='30px' bgcolor='white'><td>";
 $td_colspan2=":</td><td colspan='2'>";
 $lign_end="</td></tr>";
 $form_name="create_pack";
-
-echo "<form name='".$form_name."' id='".$form_name."' method='POST' action='' enctype='multipart/form-data'>";
+echo open_form($form_name,'',"enctype='multipart/form-data'");
 
 
 if (isset($protectedPost['valid'])){
 	looking4config();
-	//is this file exist?
-	$fSize = @filesize( $_FILES["teledeploy_file"]["tmp_name"]);
-	if( $fSize <= 0 and $protectedPost['ACTION'] != 'EXECUTE') 
-		$error=$l->g(436)." ".$_FILES["teledeploy_file"]["tmp_name"];
 
+	$fSize = @filesize( $_FILES["teledeploy_file"]["tmp_name"]);
+	//file not exist
+	if( $fSize <= 0 ){
+		if ($protectedPost['ACTION'] != 'EXECUTE') 
+			$error=$l->g(436)." ".$_FILES["teledeploy_file"]["tmp_name"];
+	}//file exist
+	else{
+		//is it a zip file or TAR.GZ file?
+		$name_file_extention=explode('.',$_FILES["teledeploy_file"]["name"]);
+		$extention=array_pop($name_file_extention);
+		if (strtoupper($extention) != "ZIP" and strtoupper($extention) != "GZ"){
+			$error=$l->g(1231);
+			//ok
+		}elseif(strtoupper($extention) == "GZ" and strtoupper(array_pop($name_file_extention)) != "TAR"){
+			$error=$l->g(1232);
+		}		
+	}
 	
 	//the package name is exist in database?
 	$verifN = "SELECT fileid FROM download_available WHERE name='%s'";
@@ -122,7 +145,9 @@ if (isset($protectedPost['valid'])){
 	$resN = mysql2_query_secure( $verifN, $_SESSION['OCS']["readServer"], $argverifN);
 	if( mysql_num_rows( $resN ) != 0 )
 	$error=$l->g(551);
-		
+	
+	
+	
 	if ($error){
 		 msg_error($error);
 		 unset($protectedPost['valid']);
@@ -404,7 +429,7 @@ if ($activate){
 		}
 		echo "<br><b>" . $l->g(1183) . ":</b>".show_modif($list_dde_creat,'LIST_DDE_CREAT',2,$form_name);
 		if (!$protectedPost['LIST_DDE_CREAT'] or $protectedPost['LIST_DDE_CREAT'] == ""){
-			echo "</form>";
+			echo close_form();
 			require_once(FOOTER_HTML);
 			die();
 		}else{
@@ -415,7 +440,7 @@ if ($activate){
 			
 		}
 	}else{
-		echo "</form>";
+		echo close_form();
 		require_once(FOOTER_HTML);
 		die();
 	}
@@ -449,6 +474,9 @@ $sous_tab_beg="<table BGCOLOR='#C7D9F5' BORDER='3'><tr><td>";
 $sous_tab_end="</td></tr></table>";
 $nom= $lign_begin.$l->g(49).$td_colspan2.show_modif($protectedPost['NAME'],'NAME',$NAME_TYPE,'',$config_input).$lign_end;
 $descr=$lign_begin.$l->g(53).$td_colspan2.show_modif($protectedPost['DESCRIPTION'],'DESCRIPTION',$DESCRIPTION_TYPE).$lign_end;
+if (!isset($protectedPost['VISIBLE']))
+$protectedPost['VISIBLE']=1;
+$visible=$lign_begin.$l->g(52).$td_colspan2.show_modif($yes_no,'VISIBLE',2,"",$configinput['DEFAULT'] = "NO").$lign_end;
 $os=$lign_begin.$l->g(25).$td_colspan2.champ_select_block($list_os,'OS',array('OS'=>'WINDOWS')).$lign_end;
 $proto=$lign_begin.$l->g(439).$td_colspan2.show_modif($list_proto,'PROTOCOLE',2,'').$lign_end;
 $prio=$lign_begin.$l->g(440).$td_colspan2.show_modif($list_prio,'PRIORITY',2,'').$lign_end;
@@ -464,7 +492,11 @@ $redistrib="<tr height='30px' bgcolor='white'><td colspan='2'>".$l->g(1008).":</
 
 echo "<table BGCOLOR='#C7D9F5' BORDER='0' WIDTH = '600px' ALIGN = 'Center' CELLPADDING='0' BORDERCOLOR='#9894B5' >";
 
-echo $title_creat.$nom.$descr.$os.$proto.$prio.$file.$action;
+echo $title_creat.$nom.$descr;
+if (isset($_SESSION['OCS']['RESTRICTION']['TELEDIFF_VISIBLE']) 
+	and $_SESSION['OCS']['RESTRICTION']['TELEDIFF_VISIBLE'] == "NO" )
+echo $visible;
+echo $os.$proto.$prio.$file.$action;
 //redistrib
 if ($_SESSION['OCS']["use_redistribution"] == 1){
 	echo $title_redistrib.$redistrib;
@@ -477,12 +509,17 @@ if ($_SESSION['OCS']["use_redistribution"] == 1){
 	if (!$default['DOWNLOAD_REP_CREAT'])
 	$default['DOWNLOAD_REP_CREAT'] = $_SERVER["DOCUMENT_ROOT"]."/download/server/";
 
-	if (!$protectedPost['REDISTRIB_REP'])
-	$protectedPost['REDISTRIB_REP']=$default['DOWNLOAD_REP_CREAT'];
+/*	if (!$protectedPost['REDISTRIB_REP'])
+		$protectedPost['REDISTRIB_REP']=$default['DOWNLOAD_REP_CREAT'];*/
 	if (!$protectedPost['REDISTRIB_PRIORITY'])
-	$protectedPost['REDISTRIB_PRIORITY']=$default['DOWNLOAD_PRIORITY'];
+		$protectedPost['REDISTRIB_PRIORITY']=$default['DOWNLOAD_PRIORITY'];
+	if (!$protectedPost['DOWNLOAD_SERVER_DOCROOT'])
+		$protectedPost['DOWNLOAD_SERVER_DOCROOT']=$default['DOWNLOAD_SERVER_DOCROOT'];
 	$redistrib_rep=$lign_begin.$l->g(829).$td_colspan2.$default['DOWNLOAD_REP_CREAT'].$lign_end;
-	$redistrib_rep_distant=$lign_begin.$l->g(1009).$td_colspan2.$default['DOWNLOAD_SERVER_DOCROOT'].$lign_end;
+	$config_input=array('MAXLENGTH'=>255,'SIZE'=>25);
+	$redistrib_rep_distant=$lign_begin.$l->g(1009).$td_colspan2.show_modif($protectedPost['DOWNLOAD_SERVER_DOCROOT'],'DOWNLOAD_SERVER_DOCROOT','0','',$config_input).$lign_end;
+	
+	//$redistrib_rep_distant=$lign_begin.$l->g(1009).$td_colspan2.$default['DOWNLOAD_SERVER_DOCROOT'].$lign_end;
 	$redistrib_prio=$lign_begin.$l->g(440).$td_colspan2.show_modif($list_prio,'REDISTRIB_PRIORITY',2,'').$lign_end;
 	echo "<tr><td colspan='3' align=center><div id='REDISTRIB_USE_div' style='display:".($protectedPost["REDISTRIB_USE"] == 1 ? " block" : "none")."'>";
 	echo $sous_tab_beg;
@@ -498,7 +535,7 @@ echo "<table BGCOLOR='#C7D9F5' BORDER='0' WIDTH = '600px' ALIGN = 'Center' CELLP
 	echo $title_user.$notify_user;
 
 		$notify_txt=$lign_begin.$l->g(449).$td_colspan2.show_modif($_POST['NOTIFY_TEXT'],'NOTIFY_TEXT',1).$lign_end;
-		$notify_count_down=$lign_begin.$l->g(450).$td_colspan2.show_modif($protectedPost['NOTIFY_COUNTDOWN'],'NOTIFY_COUNTDOWN',0,'',array('MAXLENGTH'=>4,'SIZE'=>4)).$l->g(511).$lign_end;
+		$notify_count_down=$lign_begin.$l->g(450).$td_colspan2.show_modif($protectedPost['NOTIFY_COUNTDOWN'],'NOTIFY_COUNTDOWN',0,'',array('MAXLENGTH'=>4,'SIZE'=>4,'JAVASCRIPT'=>$chiffres)).$l->g(511).$lign_end;
 		$notify_can_abord=$lign_begin.$l->g(451).$td_colspan2.show_modif($yes_no,'NOTIFY_CAN_ABORT',2).$lign_end;
 		$notify_can_delay=$lign_begin.$l->g(452).$td_colspan2.show_modif($yes_no,'NOTIFY_CAN_DELAY',2).$lign_end;
 		echo "<tr><td colspan='3' align=center><div id='NOTIFY_USER_div' style='display:".($protectedPost["NOTIFY_USER"] == 1 ? " block" : "none")."'>";
@@ -523,10 +560,10 @@ echo "</table>";
 echo "<br><input type='submit' name='valid' id='valid' value='".$l->g(13)."' OnClick='return verif();' >";
 echo "<input type='hidden' id='digest_algo' name='digest_algo' value='MD5'>
 	  <input type='hidden' id='digest_encod' name='digest_encod' value='Hexa'>
-	  <input type='hidden' id='download_rep_creat' name='download_rep_creat' value='".$default['DOWNLOAD_REP_CREAT']."'>
-	  <input type='hidden' id='download_server_docroot' name='download_server_docroot' value='".$default['DOWNLOAD_SERVER_DOCROOT']."'>";
-	  
-echo "</form></div>";
+	  <input type='hidden' id='download_rep_creat' name='download_rep_creat' value='".$default['DOWNLOAD_REP_CREAT']."'>";
+//	  <input type='hidden' id='download_server_docroot' name='download_server_docroot' value='".$default['DOWNLOAD_SERVER_DOCROOT']."'>";
+echo close_form();	  
+echo "</div>";
 
 ?>
 
