@@ -36,7 +36,7 @@ $multi_search=array("OCS_REPORT_NB_NOTIFIED"=>array("FIELD"=>'',"COMP"=>'',"VALU
 			 	    "OCS_REPORT_NB_HARD_DISK_H"=>array("FIELD"=>'',"COMP"=>'',"VALUE"=>''),
 					"OCS_REPORT_OSNAME"=>array("FIELD"=>'HARDWARE-OSNAME',"COMP"=>'',"VALUE"=>''),
 					"OCS_REPORT_USERAGENT"=>array("FIELD"=>'HARDWARE-USERAGENT',"COMP"=>'exact',"VALUE"=>''),
-					"OCS_REPORT_PROCESSORT"=>array("FIELD"=>'HARDWARE-USERAGENT',"COMP"=>'exact',"VALUE"=>''),
+					"OCS_REPORT_PROCESSORT"=>array("FIELD"=>'HARDWARE-PROCESSORT',"COMP"=>'exact',"VALUE"=>''),
 					"OCS_REPORT_RESOLUTION"=>array("FIELD"=>'VIDEOS-RESOLUTION',"COMP"=>'',"VALUE"=>''),
 					"OCS_REPORT_WORKGROUP"=>array("FIELD"=>'HARDWARE-WORKGROUP',"COMP"=>'exact',"VALUE"=>''),
 					"OCS_REPORT_TAG"=>array("FIELD"=>'ACCOUNTINFO-TAG',"COMP"=>'exact',"VALUE"=>''),
@@ -47,8 +47,8 @@ $multi_search=array("OCS_REPORT_NB_NOTIFIED"=>array("FIELD"=>'',"COMP"=>'',"VALU
 					"OCS_REPORT_NB_LIMIT_MEM_H"=>array("FIELD"=>'HARDWARE-MEMORY',"COMP"=>'tall',"VALUE"=>$data_limit['GUI_REPORT_RAM_MAX']),
 					"OCS_REPORT_NB_LIMIT_MEM_M"=>array("FIELD"=>'HARDWARE-MEMORY',"COMP"=>'small',"VALUE"=>$data_limit['GUI_REPORT_RAM_MINI']),
 					"OCS_REPORT_NB_LIMIT_MEM_B"=>array("FIELD"=>'HARDWARE-MEMORY,HARDWARE-MEMORY',"COMP"=>'tall,small',"VALUE"=>$data_limit['GUI_REPORT_RAM_MINI'].','.$data_limit['GUI_REPORT_RAM_MAX']),					
-					"OCS_REPORT_NB_NOTIFIED"=>array("FIELD"=>'DEVICES-DOWNLOAD',"COMP"=>'exact',"VALUE"=>'NULL','VALUE2'=>$l->g(482)),
-					"OCS_REPORT_NB_ERR"=>array("FIELD"=>'DEVICES-DOWNLOAD',"COMP"=>'exact',"VALUE"=>'NULL','VALUE2'=>"ERR_"),
+					"OCS_REPORT_NB_NOTIFIED"=>array("FIELD"=>'DEVICES-DOWNLOAD',"COMP"=>'exact',"VALUE"=>'NULL','VALUE2'=>$l->g(482),'TYPE_FIELD'=>"SelFieldValue"),
+					"OCS_REPORT_NB_ERR"=>array("FIELD"=>'DEVICES-DOWNLOAD',"COMP"=>'exact',"VALUE"=>'NULL','VALUE2'=>"***".$l->g(956)."***",'TYPE_FIELD'=>"SelFieldValue"),
 			/*		"OCS_REPORT_NB_HARD_DISK_H"=>array("FIELD"=>'HARDWARE-MEMORY',"COMP"=>'tall',"VALUE"=>$data_limit['GUI_REPORT_RAM_MAX']),
 					"OCS_REPORT_NB_HARD_DISK_M"=>array("FIELD"=>'HARDWARE-MEMORY',"COMP"=>'small',"VALUE"=>$data_limit['GUI_REPORT_RAM_MINI']),
 					"OCS_REPORT_NB_HARD_DISK_B"=>array("FIELD"=>'HARDWARE-MEMORY,HARDWARE-MEMORY',"COMP"=>'tall,small',"VALUE"=>$data_limit['GUI_REPORT_RAM_MINI'].','.$data_limit['GUI_REPORT_RAM_MAX']),					
@@ -108,7 +108,7 @@ $table_field=array("OCS_REPORT_WORKGROUP"=>array($l->g(33)=>"workgroup"),
 			  "OCS_REPORT_NB_HARD_DISK_M"=>"drives",
 			  "OCS_REPORT_NB_HARD_DISK_B"=>"drives"
 			  ,"OCS_REPORT_NB_IPDISCOVER"=>"networks"
-			  ,"OCS_REPORT_NB_LAST_INV"=>"hardware"
+			  ,"OCS_REPORT_NB_LAST_INV"=>array("NAME"=>"NAME","ID"=>"ID",$l->g(25)=>"osname",$l->g(218)=>"useragent"),
 					);
 					
 
@@ -241,7 +241,7 @@ $sql_field=array("OCS_REPORT_WORKGROUP"=>array('ARG'=>array('count(distinct work
 			 	 "OCS_REPORT_NB_INV"=>array('SQL'=>"select %s from %s where lastdate > date_format(sysdate(),'%s')",
 			 	 							'ARG'=>array('count(id) c',$table["OCS_REPORT_NB_INV"],"%Y-%m-%d 00:00:00")),
 
-			 	 "OCS_REPORT_NB_4_MOMENT"=>array('ARG'=>array('count(id) c',$table["OCS_REPORT_NB_4_MOMENT"],"where unix_timestamp(lastdate) < unix_timestamp(sysdate())-(".$data_limit['GUI_REPORT_AGIN_MACH']."*86400)")),
+			 	 "OCS_REPORT_NB_4_MOMENT"=>array('ARG'=>array('count(id) c',$table["OCS_REPORT_NB_4_MOMENT"],"where unix_timestamp(lastcome) < unix_timestamp(sysdate())-(".$data_limit['GUI_REPORT_AGIN_MACH']."*86400)")),
 
 			 	 "OCS_REPORT_NB_HARD_DISK_H"=>array('SQL'=>"select %s from %s where type='%s' and free>%s",
 			 	 									'ARG'=>array('count(distinct(hardware_id)) c',$table["OCS_REPORT_NB_HARD_DISK_H"],"Hard Drive",$data_limit['GUI_REPORT_DD_MAX'])),
@@ -255,7 +255,7 @@ $sql_field=array("OCS_REPORT_WORKGROUP"=>array('ARG'=>array('count(distinct work
 				 "OCS_REPORT_NB_IPDISCOVER"=>array('SQL'=>"select %s c from netmap ",
 										 'ARG'=>array(count_noinv_network_devices())),
 
-			 	 "OCS_REPORT_NB_LAST_INV"=>array('ARG'=>array('count(id) c',$table["OCS_REPORT_NB_LAST_INV"],"where floor((unix_timestamp(lastcome) - unix_timestamp(lastdate) )/86400) >= ".$data_limit['GUI_REPORT_LAST_DIFF'])),
+			 	 "OCS_REPORT_NB_LAST_INV"=>array('ARG'=>array('count(id) c',$table["OCS_REPORT_NB_LAST_INV"]," where floor((unix_timestamp(lastcome) - unix_timestamp(lastdate) )/86400) >= ".$data_limit['GUI_REPORT_LAST_DIFF']." ")),
 
 				  "OCS_REPORT_NB_SNMP"=>array('ARG'=>array('count(id) c',$table["OCS_REPORT_NB_SNMP"],''))
 			  );
@@ -263,13 +263,13 @@ $sql_field=array("OCS_REPORT_WORKGROUP"=>array('ARG'=>array('count(distinct work
 	
 function define_tab($data_on=array()){
 	global $l;
-	$data_on['ACTIVITY']=$l->g(798);
-	$data_on['SOFT']=strtoupper($l->g(20));
-	$data_on['HARD']=$l->g(799);
-	$data_on['ELSE']=$l->g(800);
+	$data_on['ACTIVITY']=mb_strtoupper($l->g(798), 'UTF-8');
+	$data_on['SOFT']=mb_strtoupper($l->g(20), 'UTF-8');
+	$data_on['HARD']=mb_strtoupper($l->g(799), 'UTF-8');
+	$data_on['ELSE']=mb_strtoupper($l->g(800), 'UTF-8');
 	if( $_SESSION['OCS']['CONFIGURATION']['CONSOLE']=="YES") {
-		//$data_on['ADMIN']['CONFIG']=strtoupper($l->g(107));
-		$data_on['ADMIN']['MSG']=strtoupper($l->g(915));
+		//$data_on['ADMIN']['CONFIG']=mb_strtoupper($l->g(107));
+		$data_on['ADMIN']['MSG']=mb_strtoupper($l->g(915), 'UTF-8');
 	
 		if (!isset($default))
 			$default = 'MSG';
@@ -395,7 +395,7 @@ function show_console_field($fields,$form_name){
 						$link_me_begin="<a href='index.php?".PAG_INDEX."=".$pages_refs[$link[$key]['PAGE']];
 						if (isset($multi_search[$key]['FIELD'])){
 							//'ARG'=>'&fields=HARDWARE-LASTCOME&comp=tall&values='.date($l->g(1242))
-							$link_me_begin.="&fields=".$multi_search[$key]['FIELD']."&comp=".$multi_search[$key]['COMP']."&values=".$multi_search[$key]['VALUE']."&values2=".$multi_search[$key]['VALUE2'];
+							$link_me_begin.="&fields=".$multi_search[$key]['FIELD']."&comp=".$multi_search[$key]['COMP']."&values=".$multi_search[$key]['VALUE']."&values2=".$multi_search[$key]['VALUE2']."&type_field=".$multi_search[$key]['TYPE_FIELD'];
 						}
 						$link_me_begin.="' target='_blank'>";
 						$link_me_end="</a>";
